@@ -18,7 +18,7 @@
  */
 
 /***************************************************************************
- * Copyright (C) 2017-2024 ZmartZone Holding BV
+ * Copyright (C) 2017-2025 ZmartZone Holding BV
  * Copyright (C) 2013-2017 Ping Identity Corporation
  * All rights reserved.
  *
@@ -529,12 +529,12 @@ static apr_byte_t oidc_check_max_session_duration(request_rec *r, oidc_cfg_t *cf
  * it also handles the case that a cookie is unexpectedly shared across multiple hosts in
  * name-based virtual hosting even though the OP(s) would be the same
  */
-static apr_byte_t oidc_check_cookie_domain(request_rec *r, oidc_cfg_t *cfg, oidc_session_t *session) {
+apr_byte_t oidc_check_cookie_domain(request_rec *r, oidc_cfg_t *cfg, oidc_session_t *session) {
 	const char *c_cookie_domain = oidc_cfg_cookie_domain_get(cfg)
 					  ? oidc_cfg_cookie_domain_get(cfg)
 					  : oidc_util_current_url_host(r, oidc_cfg_x_forwarded_headers_get(cfg));
 	const char *s_cookie_domain = oidc_session_get_cookie_domain(r, session);
-	if ((s_cookie_domain == NULL) || (_oidc_strcmp(c_cookie_domain, s_cookie_domain) != 0)) {
+	if ((s_cookie_domain == NULL) || (_oidc_strnatcasecmp(c_cookie_domain, s_cookie_domain) != 0)) {
 		oidc_warn(r,
 			  "aborting: detected attempt to play cookie against a different domain/host than issued for! "
 			  "(issued=%s, current=%s)",
@@ -888,7 +888,8 @@ apr_byte_t oidc_validate_redirect_url(request_rec *r, oidc_cfg_t *c, const char
 			url_ipv6_aware = uri.hostname;
 		}
 
-		if ((_oidc_strstr(c_host, url_ipv6_aware) == NULL) || (_oidc_strstr(url_ipv6_aware, c_host) == NULL)) {
+		if ((oidc_util_strcasestr(c_host, url_ipv6_aware) == NULL) ||
+		    (oidc_util_strcasestr(url_ipv6_aware, c_host) == NULL)) {
 			*err_str = apr_pstrdup(r->pool, "Invalid Request");
 			*err_desc = apr_psprintf(
 			    r->pool, "URL value \"%s\" does not match the hostname of the current request \"%s\"",
@@ -1428,7 +1429,7 @@ static int oidc_check_config_openid_openidc(server_rec *s, oidc_cfg_t *c) {
 		} else {
 			apr_uri_parse(s->process->pconf, oidc_cfg_provider_metadata_url_get(oidc_cfg_provider_get(c)),
 				      &r_uri);
-			if ((r_uri.scheme == NULL) || (_oidc_strcmp(r_uri.scheme, "https") != 0)) {
+			if ((r_uri.scheme == NULL) || (_oidc_strnatcasecmp(r_uri.scheme, "https") != 0)) {
 				oidc_swarn(s,
 					   "the URL scheme (%s) of the configured " OIDCProviderMetadataURL
 					   " SHOULD be \"https\" for security reasons!",
@@ -1447,7 +1448,7 @@ static int oidc_check_config_openid_openidc(server_rec *s, oidc_cfg_t *c) {
 
 	apr_uri_parse(s->process->pconf, oidc_cfg_redirect_uri_get(c), &r_uri);
 	if (!redirect_uri_is_relative) {
-		if (_oidc_strcmp(r_uri.scheme, "https") != 0) {
+		if (_oidc_strnatcasecmp(r_uri.scheme, "https") != 0) {
 			oidc_swarn(s,
 				   "the URL scheme (%s) of the configured " OIDCRedirectURI
 				   " SHOULD be \"https\" for security reasons (moreover: some Providers may reject "
@@ -1470,6 +1471,14 @@ static int oidc_check_config_openid_openidc(server_rec *s, oidc_cfg_t *c) {
 		}
 	}
 
+	if (oidc_proto_profile_dpop_mode_get(oidc_cfg_provider_get(c)) != OIDC_DPOP_MODE_OFF) {
+		if (oidc_util_key_list_first(oidc_cfg_private_keys_get(c), -1, OIDC_JOSE_JWK_SIG_STR) == NULL) {
+			oidc_serror(s, "'" OIDCDPoPMode "' is configured but the required signing keys have not been "
+				       "provided in '" OIDCPrivateKeyFiles "'/'" OIDCPublicKeyFiles "'");
+			return HTTP_INTERNAL_SERVER_ERROR;
+		}
+	}
+
 	return OK;
 }
 
@@ -1485,7 +1494,7 @@ static int oidc_check_config_oauth(server_rec *s, oidc_cfg_t *c) {
 
 	if (oidc_cfg_oauth_metadata_url_get(c) != NULL) {
 		apr_uri_parse(s->process->pconf, oidc_cfg_oauth_metadata_url_get(c), &r_uri);
-		if ((r_uri.scheme == NULL) || (_oidc_strcmp(r_uri.scheme, "https") != 0)) {
+		if ((r_uri.scheme == NULL) || (_oidc_strnatcasecmp(r_uri.scheme, "https") != 0)) {
 			oidc_swarn(s,
 				   "the URL scheme (%s) of the configured " OIDCOAuthServerMetadataURL
 				   " SHOULD be \"https\" for security reasons!",
@@ -1665,28 +1674,28 @@ static int oidc_post_config(apr_pool_t *pool, apr_pool_t *p1, apr_pool_t *p2, se
 		return OK;
 	}
 
+#ifdef USE_MEMCACHE
+#define _OIDC_USE_MEMCACHE "yes"
+#else
+#define _OIDC_USE_MEMCACHE "no"
+#endif
+
+#ifdef USE_LIBHIREDIS
+#define _OIDC_USE_REDIS "yes"
+#else
+#define _OIDC_USE_REDIS "no"
+#endif
+
+#ifdef USE_LIBJQ
+#define _OIDC_USE_JQ "yes"
+#else
+#define _OIDC_USE_JQ "no"
+#endif
+
 	ap_log_error(APLOG_MARK, APLOG_INFO, 0, s,
 		     "%s - init - cjose %s, %s, EC=%s, GCM=%s, Memcache=%s, Redis=%s, JQ=%s", NAMEVERSION,
 		     cjose_version(), oidc_util_openssl_version(s->process->pool), OIDC_JOSE_EC_SUPPORT ? "yes" : "no",
-		     OIDC_JOSE_GCM_SUPPORT ? "yes" : "no",
-#ifdef USE_MEMCACHE
-		     "yes"
-#else
-		     "no"
-#endif
-		     ,
-#ifdef USE_LIBHIREDIS
-		     "yes"
-#else
-		     "no"
-#endif
-		     ,
-#ifdef USE_LIBJQ
-		     "yes"
-#else
-		     "no"
-#endif
-	);
+		     OIDC_JOSE_GCM_SUPPORT ? "yes" : "no", _OIDC_USE_MEMCACHE, _OIDC_USE_REDIS, _OIDC_USE_JQ);
 
 	oidc_http_init();
 
